#!/usr/bin/env python

"""
usage: pyre_dealer01.py [-h] [-c COUNT] [-m MESSAGE] [-v]

synopsis:
  a simple Pyre dealer/server

optional arguments:
  -h, --help            show this help message and exit
  -c COUNT, --count COUNT
                        number of messages to send. Default: 2
  -m MESSAGE, --message MESSAGE
                        a message body to be sent
  -v, --verbose         Print messages during actions.

examples:
  python dealer01.py
  python dealer01.py --count=4
  python dealer01.py -c 4 --message="a simple message"
"""


#
# imports
from __future__ import print_function
import sys
import argparse
import socket
import json
import pyre

if sys.version_info.major == 2:
    input = raw_input


#
# Global variables

Node_name = socket.gethostname()
Node_value = '{} server'.format(Node_name)
Group_name = 'group1'


#
# Private functions

def dbg_msg(options, msg):
    """Print a message if verbose is on."""
    if options.verbose:
        print(msg)


#
# Exported functions

def run(opts):
    node = pyre.Pyre(Node_name)
    node.set_header(Node_name, Node_value)
    node.start()
    #node.join(Group_name)
    for idx in range(opts.count):
        response = input('{}. Press Enter.  "q"/"quit" to leave: '.format(idx))
        if response in ('q', 'quit'):
            break
        msg = '{}. {}'.format(idx, opts.message)
        body = {'host': Node_name, 'data': msg}
        bodys = json.dumps(body)
        print('sending: "{}"'.format(bodys))
        node.shouts(Group_name, bodys)
    node.leave(Group_name)
    node.stop()


def main():
    description = """\
synopsis:
  a simple Pyre dealer/server
"""
    epilog = """\
examples:
  python dealer01.py
  python dealer01.py --count=4
  python dealer01.py -c 4 --message="a simple message"
"""
    parser = argparse.ArgumentParser(
        description=description,
        epilog=epilog,
        formatter_class=argparse.RawDescriptionHelpFormatter,
    )
#     parser.add_argument(
#         "command",
#         help="A command, one of: getlist, getone, add, update, delete"
#     )
    parser.add_argument(
        "-c", "--count",
        type=int, default=2,
        help="number of messages to send.  Default: 2",
    )
    parser.add_argument(
        "-m", "--message",
        default='default message',
        help="a message body to be sent",
    )
    parser.add_argument(
        "-v", "--verbose",
        action="store_true",
        help="Print messages during actions.",
    )
    options = parser.parse_args()
    run(options)


if __name__ == '__main__':
    # import pdb; pdb.set_trace()
    # import ipdb; ipdb.set_trace()
    main()
